@@ -54,4 +54,4 @@ class AuthorizedMixin(PermissionRequiredMixin):
             permission_action = 'delete'
 
         cls.permission_required = \
-                get_permission_full_codename(permission_action, cls.model)
+                get_permission_full_codename(cls.model, permission_action)
